@@ -10,7 +10,7 @@
 #' See `View(pct_regions_lookup)` for a full list of possible region names.
 #' @param layer The PCT layer of interest, `z`, `c`, `l`, `rf`, `rq` or `rnet`
 #' for zones, centroids, desire lines, routes (fast or quiet) and route networks, respectively
-#' @param extension The type of file to download (typically `.Rds`)
+#' @param extension The type of file to download (only `.geojson` supported at present)
 #' @param national Download nationwide data? `FALSE` by default
 #' @export
 #' @examples
@@ -24,12 +24,12 @@
 #' z_all = get_pct(layer = "z", national = TRUE)
 #' }
 get_pct = function(
-  base_url = "https://github.com/npct/pct-outputs-regional-R/raw/master",
+  base_url = "https://github.com/npct/pct-outputs-regional-notR/raw/master",
   purpose = "commute",
   geography = "msoa",
   region = NULL,
   layer = NULL,
-  extension = ".Rds",
+  extension = ".geojson",
   national = FALSE
 ) {
   layers = c("z", "c", "l", "rf", "rq", "rnet")
@@ -37,12 +37,13 @@ get_pct = function(
     stop(c("Layer needs to be one of: ",
          paste0(layers, collapse = ", "), "."))
   if(national & is.character(purpose)) {
+    extension = ".Rds"
     layer = paste0(layer, "_all")
     base_url = "https://github.com/npct/pct-outputs-national/raw/master"
     u_folder = paste(base_url, purpose, geography, sep = "/")
     f = paste0(layer, extension)
     u_file = paste(u_folder, f, sep = "/")
-
+    return(sf_object = sf::st_as_sf(readRDS(url(u_file))))
   } else {
     if(length(region) != 1L)
       stop("'region' must be of length 1")
@@ -59,12 +60,7 @@ get_pct = function(
     f = paste0(layer, extension)
     u_file = paste(u_folder, f, sep = "/")
   }
-  destfile = file.path(tempdir(), f)
-  utils::download.file(url = u_file,
-                       destfile = destfile, mode = "wb")
-  sf_object = sf::st_as_sf(readRDS(destfile))
-  suppressWarnings({sf::st_crs(sf_object) = 4326})
-  sf_object
+  sf::read_sf(u_file)
 }
 #' Get zone results from the PCT
 #'
@@ -79,13 +75,12 @@ get_pct_zones = function(
   region = NULL,
   purpose = "commute",
   geography = "msoa",
-  extension = ".Rds"
+  extension = ".geojson"
 ) {
-  get_pct(base_url =
-            "https://github.com/npct/pct-outputs-regional-R/raw/master",
+  get_pct(base_url = "https://github.com/npct/pct-outputs-regional-notR/raw/master",
           purpose, geography, region,
           layer = "z",
-          extension = ".Rds")
+          extension = ".geojson")
 }
 
 #' Get centroid results from the PCT
@@ -101,13 +96,13 @@ get_pct_centroids = function(
   region = NULL,
   purpose = "commute",
   geography = "msoa",
-  extension = ".Rds"
+  extension = ".geojson"
 ) {
   get_pct(base_url =
-            "https://github.com/npct/pct-outputs-regional-R/raw/master",
+            "https://github.com/npct/pct-outputs-regional-notR/raw/master",
           purpose, geography, region,
           layer = "c",
-          extension = ".Rds")
+          extension = ".geojson")
 }
 
 #' Get desire lines results from the PCT
@@ -123,13 +118,13 @@ get_pct_lines = function(
   region = NULL,
   purpose = "commute",
   geography = "msoa",
-  extension = ".Rds"
+  extension = ".geojson"
 ) {
   get_pct(base_url =
-            "https://github.com/npct/pct-outputs-regional-R/raw/master",
+            "https://github.com/npct/pct-outputs-regional-notR/raw/master",
           purpose, geography, region,
           layer = "l",
-          extension = ".Rds")
+          extension = ".geojson")
 }
 
 #' Get fast road network results from the PCT
@@ -145,13 +140,13 @@ get_pct_routes_fast = function(
   region = NULL,
   purpose = "commute",
   geography = "msoa",
-  extension = ".Rds"
+  extension = ".geojson"
 ) {
   get_pct(base_url =
-            "https://github.com/npct/pct-outputs-regional-R/raw/master",
+            "https://github.com/npct/pct-outputs-regional-notR/raw/master",
           purpose, geography, region,
           layer = "rf",
-          extension = ".Rds")
+          extension = ".geojson")
 }
 
 #' Get quiet road network results from the PCT
@@ -167,13 +162,13 @@ get_pct_routes_quiet = function(
   region = NULL,
   purpose = "commute",
   geography = "msoa",
-  extension = ".Rds"
+  extension = ".geojson"
 ) {
   get_pct(base_url =
-            "https://github.com/npct/pct-outputs-regional-R/raw/master",
+            "https://github.com/npct/pct-outputs-regional-notR/raw/master",
           purpose, geography, region,
           layer = "rq",
-          extension = ".Rds")
+          extension = ".geojson")
 }
 
 #' Get road network results from the PCT
@@ -189,10 +184,10 @@ get_pct_rnet = function(
   region = NULL,
   purpose = "commute",
   geography = "msoa",
-  extension = ".Rds"
+  extension = ".geojson"
 ) {
-  get_pct(base_url = "https://github.com/npct/pct-outputs-regional-R/raw/master",
+  get_pct(base_url = "https://github.com/npct/pct-outputs-regional-notR/raw/master",
           purpose, geography, region,
           layer = "rnet",
-          extension = ".Rds")
+          extension = ".geojson")
 }
